Licenses
========

Except where explicitly noted otherwise, the usage of baseband and all of its
routines is governed by the GPL v3 public license (see LICENSE in the top
package directory), like the C library by Walter Brisken which inspired it.

This directory holds license and credit information for works baseband is
derived from or distributes, and/or datasets.

Marten van Kerkwijk, Oct 14, 2015


